==> seamonkey-1.1.source.tar.bz2: mozilla/extensions/java/xpcom/src/dlldeps-javaxpcom.cpp <==
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Java XPCOM Bindings.
 *
 * The Initial Developer of the Original Code is IBM Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2006
 * IBM Corporation. All Rights Reserved.
 *
 * Contributor(s):
 *   Javier Pedemonte (jhpedemonte@gmail.com)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsJavaInterfaces.h"


void XXXNeverCalled_javaxpcom()
{
  MOZILLA_NATIVE(initialize) (nsnull, nsnull);

  GRE_NATIVE(initEmbedding) (nsnull, nsnull, nsnull, nsnull, nsnull);

  GRE_NATIVE(termEmbedding) (nsnull, nsnull);

  GRE_NATIVE(lockProfileDirectory) (nsnull, nsnull, nsnull);

  GRE_NATIVE(notifyProfile) (nsnull, nsnull);

  XPCOM_NATIVE(initXPCOM) (nsnull, nsnull, nsnull, nsnull);

  XPCOM_NATIVE(shutdownXPCOM) (nsnull, nsnull, nsnull);

  XPCOM_NATIVE(newLocalFile) (nsnull, nsnull, nsnull, nsnull);

  XPCOM_NATIVE(getComponentManager) (nsnull, nsnull);

  XPCOM_NATIVE(getComponentRegistrar) (nsnull, nsnull);

  XPCOM_NATIVE(getServiceManager) (nsnull, nsnull);

  JAVAPROXY_NATIVE(callXPCOMMethod) (nsnull, nsnull, nsnull, nsnull, nsnull);

  JAVAPROXY_NATIVE(finalizeProxy) (nsnull, nsnull, nsnull);

  JAVAPROXY_NATIVE(isSameXPCOMObject) (nsnull, nsnull, nsnull, nsnull);

  LOCKPROXY_NATIVE(release) (nsnull, nsnull, nsnull);
}

==> seamonkey-1.1.18.source.tar.bz2: mozilla/extensions/java/xpcom/src/dlldeps-javaxpcom.cpp <==
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Java XPCOM Bindings.
 *
 * The Initial Developer of the Original Code is IBM Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2006
 * IBM Corporation. All Rights Reserved.
 *
 * Contributor(s):
 *   Javier Pedemonte (jhpedemonte@gmail.com)
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#include "nsJavaInterfaces.h"


void XXXNeverCalled_javaxpcom()
{
  MOZILLA_NATIVE(initialize) (nsnull, nsnull);

  GRE_NATIVE(initEmbedding) (nsnull, nsnull, nsnull, nsnull, nsnull);

  GRE_NATIVE(termEmbedding) (nsnull, nsnull);

  GRE_NATIVE(lockProfileDirectory) (nsnull, nsnull, nsnull);

  GRE_NATIVE(notifyProfile) (nsnull, nsnull);

  XPCOM_NATIVE(initXPCOM) (nsnull, nsnull, nsnull, nsnull);

  XPCOM_NATIVE(shutdownXPCOM) (nsnull, nsnull, nsnull);

  XPCOM_NATIVE(newLocalFile) (nsnull, nsnull, nsnull, nsnull);

  XPCOM_NATIVE(getComponentManager) (nsnull, nsnull);

  XPCOM_NATIVE(getComponentRegistrar) (nsnull, nsnull);

  XPCOM_NATIVE(getServiceManager) (nsnull, nsnull);

  JAVAPROXY_NATIVE(callXPCOMMethod) (nsnull, nsnull, nsnull, nsnull, nsnull);

  JAVAPROXY_NATIVE(finalizeProxy) (nsnull, nsnull, nsnull);

  JAVAPROXY_NATIVE(isSameXPCOMObject) (nsnull, nsnull, nsnull, nsnull);

  LOCKPROXY_NATIVE(release) (nsnull, nsnull, nsnull);

  MOZILLA_NATIVE(getNativeHandleFromAWT) (nsnull, nsnull, nsnull);

  JXUTILS_NATIVE(wrapJavaObject) (nsnull, nsnull, nsnull, nsnull);

  JXUTILS_NATIVE(wrapXPCOMObject) (nsnull, nsnull, nsnull, nsnull);
}
